@@ -1,10 +1,14 @@
-# Copyright (C) 2009-2013  Roman Zimbelmann <hut@lavabit.com>
-# This software is distributed under the terms of the GNU GPL version 3.
+# This file is part of ranger, the console file manager.
+# License: GNU GPL version 3, see the file "AUTHORS" for details.
+
+from __future__ import (absolute_import, division, print_function)
 
 from ranger.gui.colorscheme import ColorScheme
-from ranger.gui.color import *
+from ranger.gui.color import default_colors, reverse, bold, BRIGHT
+
 
 class Snow(ColorScheme):
+
     def use(self, context):
         fg, bg, attr = default_colors
 
@@ -16,6 +20,7 @@ class Snow(ColorScheme):
                 attr = reverse
             if context.directory:
                 attr |= bold
+                fg += BRIGHT
 
         elif context.highlight:
             attr |= reverse
@@ -32,6 +37,7 @@ class Snow(ColorScheme):
         elif context.in_taskview:
             if context.selected:
                 attr |= bold
+                fg += BRIGHT
             if context.loaded:
                 attr |= reverse
 
